@@ -1,14 +1,20 @@
 use warnings;
 use strict;
-package Test::Module 0.002; # TRIAL
+package Test::Module 0.003; # TRIAL
 
-# ABSTRACT: brief summary of what this module is used for
+# ABSTRACT: This is an example module
 
 use Exporter 'import';
 our (@EXPORT_OK) = ();
 our (@EXPORT)    = (@EXPORT_OK);
 
 
+
+sub new {
+    my $pkg = shift;
+    bless {}, $pkg;
+}
+
 1;
 
 __END__
@@ -19,17 +25,24 @@ __END__
 
 =head1 NAME
 
-Test::Module - brief summary of what this module is used for
+Test::Module - This is an example module
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
     use Test::Module;
 
-    ## ... code that uses your package
+    my $obj = new Test::Module;
+    print "Hello World\n" if $obj->isa('Test::Module');
+
+=head1 METHODS
+
+=head2 new
+
+Takes no arguments and returns a blessed reference.
 
 =head1 AUTHOR
 
